From 1e684f65a2f06e8c49ab71f4e5a14891bb6b2fed Mon Sep 17 00:00:00 2001
From: Paul Kaplan <pkaplan@media.mit.edu>
Date: Mon, 20 Nov 2017 11:49:06 -0500
Subject: [PATCH] Add integration test for stage block differences

---
 test/integration/test.js | 5 ++++-
 1 file changed, 4 insertions(+), 1 deletion(-)

diff --git a/test/integration/test.js b/test/integration/test.js
index cfea4e217..4096c2d90 100644
--- a/test/integration/test.js
+++ b/test/integration/test.js
@@ -54,8 +54,11 @@ describe('costumes, sounds and variables', () => {
         // "meow" sound block should be visible
         await findByText('meow', blocksTabScope);
         await clickText('Backdrops'); // Switch to the backdrop
         // Now "pop" sound block should be visible
         await findByText('pop', blocksTabScope);
+        await clickText('Motion', blocksTabScope);
+        await findByText('Stage selected: no motion blocks');
+
         const logs = await getLogs(errorWhitelist);
         await expect(logs).toEqual([]);
     });
@@ -54,8 +54,11 @@ describe('costumes, sounds and variables', () => {
         await findByText('meow', blocksTabScope);
         await clickText('Backdrops'); // Switch to the backdrop
-        // Now "pop" sound block should be visible
+        // Now "pop" sound block should be visible and motion blocks hidden
         await findByText('pop', blocksTabScope);
-- 
GitLab